@@ -322,6 +322,22 @@ The authentication handling code
 
 The URI handling code
 
+=item Sys::Virt::Error::FROM_DBUS
+
+The DBus handling code
+
+=item Sys::Virt::Error::FROM_DEVICE
+
+The device handling code
+
+=item Sys::Virt::Error::FROM_SSH
+
+The libSSH2 socket client
+
+=item Sys::Virt::Error::FROM_PARALLELS
+
+The Parallels virtualization driver
+
 =back
 
 =head2 ERROR CODE CONSTANTS
@@ -660,10 +676,26 @@ The requested metadata does not exist
 
 The migration operation would be unsafe to perform
 
-=item Sys::Virt::ERror::ERR_OVERFLOW
+=item Sys::Virt::Error::ERR_OVERFLOW
 
 The calculation would overflow
 
+=item Sys::Virt::Error::ERR_BLOCK_COPY_ACTIVE
+
+Action prevented by block copy job
+
+=item Sys::Virt::Error::ERR_AGENT_UNRESPONSIVE
+
+The guest agent is not responding
+
+=item Sys::Virt::Error::ERR_OPERATION_UNSUPPORTED
+
+The operation is not supported on this host
+
+=item Sys::Virt::Error::ERR_SSH
+
+The SSH operation failed
+
 =back
 
 =head1 AUTHORS
